@@ -195,15 +195,11 @@ class GDownloadProgressListener;
 struct MimeAskActionDialog;
 struct HelperAppChooserDialog;
 
-extern "C"
-void mime_ask_dialog_save_clicked_cb (GtkButton *button,
-				      MimeAskActionDialog *dialog);
-extern "C"
-void mime_ask_dialog_open_clicked_cb (GtkButton *button,
-				      MimeAskActionDialog *dialog);
-extern "C"
-gint mime_ask_dialog_cancel_clicked_cb (GtkButton *button,
-					MimeAskActionDialog *dialog);
+enum
+{
+	RESPONSE_SAVE = 1,
+	RESPONSE_OPEN = 2
+};
 
 /*
  * MimeAskActionDialog: the representation of dialogs used to ask
@@ -246,7 +242,7 @@ GContentHandler::~GContentHandler()
 // begin nsIHelperAppLauncher impl
 ////////////////////////////////////////////////////////////////////////////////
 
-#if MOZILLA_SNAPSHOT > 8
+#if MOZILLA_SNAPSHOT > 9
 /* void show (in nsIHelperAppLauncher aLauncher, in nsISupports aContext); */
 NS_IMETHODIMP GContentHandler::Show(nsIHelperAppLauncher *aLauncher,
 				    nsISupports *aContext,
@@ -273,7 +269,7 @@ NS_IMETHODIMP GContentHandler::Show(nsIHelperAppLauncher *aLauncher,
 
 /* nsILocalFile promptForSaveToFile (in nsISupports aWindowContext, in wstring aDefaultFile, in wstring aSuggestedFileExtension); */
 NS_IMETHODIMP GContentHandler::PromptForSaveToFile(
-#if MOZILLA_SNAPSHOT > 9
+#if MOZILLA_SNAPSHOT > 10
 				    nsIHelperAppLauncher *aLauncher,
 #endif				    
 				    nsISupports *aWindowContext,
@@ -343,7 +339,7 @@ NS_IMETHODIMP GContentHandler::PromptForSaveToFile(
 	}
 }
 
-#if MOZILLA_SNAPSHOT < 9
+#if MOZILLA_SNAPSHOT < 10
 /* void showProgressDialog (in nsIHelperAppLauncher aLauncher, in nsISupports aContext); */
 NS_METHOD GContentHandler::ShowProgressDialog(nsIHelperAppLauncher *aLauncher,
 					      nsISupports *aContext)
@@ -498,18 +494,18 @@ NS_METHOD GContentHandler::Init (void)
 	rv = mLauncher->GetMIMEInfo (getter_AddRefs(MIMEInfo));
 	rv = MIMEInfo->GetMIMEType (&mMimeType);
 	
+#if MOZILLA_SNAPSHOT > 11
+	rv = mLauncher->GetSource(getter_AddRefs(mUri));
+	rv = mLauncher->GetTargetFile(getter_AddRefs(mTempFile));
+#else
 	rv = mLauncher->GetDownloadInfo(getter_AddRefs(mUri),
 					&mTimeDownloadStarted,
 					getter_AddRefs(mTempFile));
+#endif
+	
 	rv = mUri->GetSpec (mUrl);
 	rv = mUri->GetScheme (mScheme);
-#if 0
-	/* GetSource seems redundant and isn't in 0.9 This code is here while
-	   it remains unclear what GetSource is for. --phil */
-	nsCOMPtr<nsIURI> uri;
-	rv = mLauncher->GetSource(getter_AddRefs(uri));
-	rv = uri->GetSpec (mUrl);
-#endif	
+	
 	ProcessMimeInfo ();
 
 	return NS_OK;
@@ -601,8 +597,8 @@ MimeAskActionDialog::~MimeAskActionDialog()
 // begin MIMEAskActionDialog callbacks.
 ////////////////////////////////////////////////////////////////////////////////
 
-extern "C" void
-mime_ask_dialog_save_clicked_cb (GtkButton *button, MimeAskActionDialog *dialog)
+static void
+mime_ask_dialog_save (MimeAskActionDialog *dialog)
 {
 	gtk_widget_hide (glade_xml_get_widget (dialog->mGXml, 
 					       "mime_ask_action_dialog"));
@@ -617,7 +613,7 @@ mime_ask_dialog_save_clicked_cb (GtkButton *button, MimeAskActionDialog *dialog)
 }
 
 static void
-mime_ask_dialog_download_cancel (MimeAskActionDialog *dialog)
+mime_ask_dialog_cancel (MimeAskActionDialog *dialog)
 {
 	nsresult rv;
 	nsCOMPtr<nsIHelperAppLauncher> launcher;
@@ -628,8 +624,8 @@ mime_ask_dialog_download_cancel (MimeAskActionDialog *dialog)
 	delete dialog;
 }
 
-extern "C" void
-mime_ask_dialog_open_clicked_cb (GtkButton *button, MimeAskActionDialog *dialog)
+static void
+mime_ask_dialog_open (MimeAskActionDialog *dialog)
 {
 	nsresult rv;
 	nsCOMPtr<nsIHelperAppLauncher> launcher;
@@ -644,15 +640,23 @@ mime_ask_dialog_open_clicked_cb (GtkButton *button, MimeAskActionDialog *dialog)
 	}
 	else
 	{	
-		mime_ask_dialog_download_cancel (dialog);
+		mime_ask_dialog_cancel (dialog);
 		ephy_embed_utils_nohandler_dialog_run (dialog->mParent);
 	}
 }
 
-extern "C" gint
-mime_ask_dialog_cancel_clicked_cb (GtkButton *button,
-				   MimeAskActionDialog *dialog)
+extern "C" void
+mime_ask_dialog_response_cb (GtkDialog *gtkdialog, int response, MimeAskActionDialog *dialog)
 {
-	mime_ask_dialog_download_cancel (dialog);
-	return 0; /* FIXME: philipl, is this the right thing to return? */
+	switch (response)
+	{
+		case RESPONSE_SAVE:
+			mime_ask_dialog_save (dialog);
+			break;
+		case RESPONSE_OPEN:
+			mime_ask_dialog_open (dialog);
+			break;
+		default:
+			mime_ask_dialog_cancel (dialog);
+	}
 }
