@@ -156,6 +156,7 @@ impl_save (EphyEmbedPersist *persist)
 	EphyEmbed *embed;
 	EmbedPersistFlags flags;
 	EphyWrapper *wrapper = NULL;
+	PRUint32 persistFlags = 0;
 
 	g_object_ref (persist);
 	
@@ -209,27 +210,27 @@ impl_save (EphyEmbedPersist *persist)
 		wrapper->GetDOMWindow (getter_AddRefs (parent));
 	}
 
+	persistFlags = nsIWebBrowserPersist::PERSIST_FLAGS_REPLACE_EXISTING_FILES;
+
 	size_t len = strlen(filename);
 	if((filename[len-1] == 'z' && filename[len-2] == 'g') ||
 	   (filename[len-1] == 'Z' && filename[len-2] == 'G'))
 	{
-                bpersist->SetPersistFlags (nsIWebBrowserPersist::PERSIST_FLAGS_NO_CONVERSION);
-	}
-        else
-	{
-        	bpersist->SetPersistFlags (nsIWebBrowserPersist::PERSIST_FLAGS_NONE);
+                persistFlags |= nsIWebBrowserPersist::PERSIST_FLAGS_NO_CONVERSION;
 	}
 
 	if (flags & EMBED_PERSIST_BYPASSCACHE)
 	{
-		bpersist->SetPersistFlags (nsIWebBrowserPersist::PERSIST_FLAGS_BYPASS_CACHE);
+		persistFlags |= nsIWebBrowserPersist::PERSIST_FLAGS_BYPASS_CACHE;
 	}
 
 	if (flags & EMBED_PERSIST_FROMCACHE)
 	{
-		bpersist->SetPersistFlags (nsIWebBrowserPersist::PERSIST_FLAGS_FROM_CACHE);
+		persistFlags |= nsIWebBrowserPersist::PERSIST_FLAGS_FROM_CACHE;
 	}
 
+	bpersist->SetPersistFlags (persistFlags);
+
 	GProgressListener *aProgress = new GProgressListener ();
 	MOZILLA_EMBED_PERSIST (persist)->priv->mProgress = aProgress;
 
@@ -253,9 +254,19 @@ impl_save (EphyEmbedPersist *persist)
                                 do_QueryInterface (DOMDocument, &rv);
         	if (NS_FAILED(rv) || !document) return G_FAILED;
 
+#if MOZILLA_SNAPSHOT > 13
+		nsIURI *uri;
+		uri = document->GetDocumentURI ();
+		if (!uri) return G_FAILED;
+#elif MOZILLA_SNAPSHOT > 11
+		nsIURI *uri;
+		uri = document->GetDocumentURL ();
+		if (!uri) return G_FAILED;
+#else
 	        nsCOMPtr<nsIURI> uri;
         	rv = document->GetDocumentURL (getter_AddRefs(uri));
         	if (NS_FAILED(rv) || !uri) return G_FAILED;
+#endif
 
         	aProgress->InitForPersist (bpersist, parent,
                    	                   uri, file, 
