@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-new-bookmark.h,v 1.6 2003/05/13 14:19:07 Bordoley Exp $
+ *  $Id: ephy-new-bookmark.h,v 1.7 2003/06/09 11:49:43 mpeseng Exp $
  */
 
 #ifndef EPHY_NEW_BOOKMARK_H
@@ -64,9 +64,6 @@ void		     ephy_new_bookmark_set_title    (EphyNewBookmark *bookmark,
 void		     ephy_new_bookmark_set_icon     (EphyNewBookmark *bookmark,
 						     const char *icon);
 
-void		     ephy_new_bookmark_set_smarturl (EphyNewBookmark *bookmark,
-						     const char *url);
-
 gulong		     ephy_new_bookmark_get_id       (EphyNewBookmark *bookmark);
 
 G_END_DECLS
