@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: pdm-dialog.c,v 1.19 2003/07/27 12:26:10 chpe Exp $
+ * $Id: pdm-dialog.c,v 1.19.2.1 2004/02/27 11:28:39 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -357,7 +357,13 @@ pdm_cmd_delete_selection (PdmActionInfo *action)
 	selection = gtk_tree_view_get_selection
 		(GTK_TREE_VIEW(action->treeview));
 	llist = gtk_tree_selection_get_selected_rows (selection, &model);
-	
+
+	if (llist == NULL)
+	{
+		/* nothing to delete, return early */
+		return;
+	}
+
 	for (l = llist;l != NULL; l = l->next)
 	{
 		rlist = g_list_prepend (rlist, gtk_tree_row_reference_new
